[llvm] r207043 - Use std::less instead of < in array_pod_sort's default comparator.

Jordan Rose jordan_rose at apple.com
Wed Apr 23 15:44:11 PDT 2014


Author: jrose
Date: Wed Apr 23 17:44:11 2014
New Revision: 207043

URL: http://llvm.org/viewvc/llvm-project?rev=207043&view=rev
Log:
Use std::less instead of < in array_pod_sort's default comparator.

This makes array_pod_sort portably safe to use with pointers.

Modified:
    llvm/trunk/include/llvm/ADT/STLExtras.h

Modified: llvm/trunk/include/llvm/ADT/STLExtras.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/ADT/STLExtras.h?rev=207043&r1=207042&r2=207043&view=diff
==============================================================================
--- llvm/trunk/include/llvm/ADT/STLExtras.h (original)
+++ llvm/trunk/include/llvm/ADT/STLExtras.h Wed Apr 23 17:44:11 2014
@@ -171,13 +171,14 @@ LLVM_CONSTEXPR inline size_t array_lengt
   return N;
 }
 
-/// array_pod_sort_comparator - This is helper function for array_pod_sort,
-/// which just uses operator< on T.
+/// Adapt std::less<T> for array_pod_sort.
 template<typename T>
 inline int array_pod_sort_comparator(const void *P1, const void *P2) {
-  if (*reinterpret_cast<const T*>(P1) < *reinterpret_cast<const T*>(P2))
+  if (std::less<T>()(*reinterpret_cast<const T*>(P1),
+                     *reinterpret_cast<const T*>(P2)))
     return -1;
-  if (*reinterpret_cast<const T*>(P2) < *reinterpret_cast<const T*>(P1))
+  if (std::less<T>()(*reinterpret_cast<const T*>(P2),
+                     *reinterpret_cast<const T*>(P1)))
     return 1;
   return 0;
 }
@@ -200,7 +201,7 @@ inline int (*get_array_pod_sort_comparat
 /// possible.
 ///
 /// This function assumes that you have simple POD-like types that can be
 /// compared with operator< and can be moved with memcpy.  If this isn't true,
 /// you should use std::sort.
 ///
 /// NOTE: If qsort_r were portable, we could allow a custom comparator and
@@ -200,7 +201,7 @@ inline int (*get_array_pod_sort_comparat
 ///
 /// This function assumes that you have simple POD-like types that can be
-/// compared with operator< and can be moved with memcpy.  If this isn't true,
+/// compared with std::less and can be moved with memcpy.  If this isn't true,
 /// you should use std::sort.
 ///





More information about the llvm-commits mailing list